Wintersong - Components

# Components

## Audio player

Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum

## Carousel

## Image map

Mainboard Faceplate 1/8" jacks (8) Hex nuts for the 1/8" jacks (8) Eurorack power header Rubber bands (2) Big knob Small knobs (3) Tall trimmer pots (3) 9mm pots (4) Washers for 9mm pots (4) Nuts for 9mm pots (4)